==> wasup-svr-7.0.tar.gz: wasup-svr-7.0/bin/env.sh <==
#!/bin/bash

#************************ Warning **********************************
#*                                                                 *
#* This configuration is property of OPEN SOURCE CONSULTING, INC.  *
#* Don't distribute this to other project.                         *
#*                                                                 *
#* Contact jchoi@osci.kr(http://www.osci.kr)                       *
#*******************************************************************

#####################################
# This is tomcat env.sh for iosp by Open Source Consulting, Inc
#####################################
export DATE=`date +%Y%m%d_%H%M%S`

#####################################
## Set Tomcat base env
#####################################
export JAVA_HOME=/opt/WASup/jdk/zulu8.33.0.1-jdk8.0.192-linux_x64
export SERVER_NAME=wasup-svr
export SERVER=wasup-svr
export CATALINA_HOME=/opt/WASup/engines/wasup-7.0
export CATALINA_BASE=/opt/WASup/servers/$SERVER_NAME
export CONF_DIR=${CATALINA_BASE}/conf
export LOG_BASE=${CATALINA_BASE}/logs
export LOG_DIR=${LOG_BASE}
export GC_LOG_DIR=${LOG_DIR}/tmp

export PORT_OFFSET=0
export COMP_USER=osc

export JVM_ROUTE=$SERVER_NAME

#####################################
##### Tomcat Cluster #####
#####################################
#export BIND_ADDR=20.20.20.11
#export MULTICAST_ADDR=230.111.222.244
#export CLUSTER_PORT=$(expr 7600 + $PORT_OFFSET)

#####################################
## Set Port Configuration
#####################################
#  Default Ports are as below       
#  HTTP_PORT	    : 8080	    
#  SSL_PORT 	    : 8443	    
#  SHUTDOWN_PORT    : 8005	    
#  RMI_PORT         : 9999	    
#####################################

CUSTOM_HTTP_PORT=
CUSTOM_AJP_PORT=
CUSTOM_SSL_PORT=
CUSTOM_SHUTDOWN_PORT=
CUSTOM_RMI_PORT=
CUSTOM_JVM_OPTIONS=

if [ "x$CUSTOM_HTTP_PORT" = "x" ]; then
    export HTTP_PORT=$(expr 8080 + $PORT_OFFSET)
else
    export HTTP_PORT=$CUSTOM_HTTP_PORT
fi

if [ "x$CUSTOM_AJP_PORT" = "x" ]; then
    export AJP_PORT=$(expr 8009 + $PORT_OFFSET)
else
    export AJP_PORT=$CUSTOM_AJP_PORT
fi

if [ "x$CUSTOM_SSL_PORT" = "x" ]; then
    export SSL_PORT=$(expr 8443 + $PORT_OFFSET)
else
    export SSL_PORT=$CUSTOM_SSL_PORT
fi

if [ "x$CUSTOM_SHUTDOWN_PORT" = "x" ]; then
    export SHUTDOWN_PORT=$(expr 8005 + $PORT_OFFSET)
else
    export SHUTDOWN_PORT=$CUSTOM_SHUTDOWN_PORT
fi

if [ "x$CUSTOM_RMI_PORT" = "x" ]; then
    export RMI_PORT=$(expr 9999 + $PORT_OFFSET)
else
    export RMI_PORT=$CUSTOM_RMI_PORT
fi

if [ "x$CUSTOM_JVM_OPTIONS" = "x" ]; then
    export JVM_OPTIONS="-Xms1024m -Xmx1024m -XX:MetaspaceSize=256m -XX:MaxMetaspaceSize=256m"
else
    export JVM_OPTIONS=$CUSTOM_JVM_OPTIONS
fi

#####################################
## JVM Parameter Configuration
#####################################

# Remove the JAVA_OPTS environment variable.
# Initialize required in case of start by WASup agent process.
unset JAVA_OPTS

if [ "x$JAVA_OPTS" = "x" ]; then
    JAVA_OPTS="-server"
    JAVA_OPTS="$JAVA_OPTS -Dserver=$SERVER"
    JAVA_OPTS="$JAVA_OPTS -Djvmid=$SERVER"
    JAVA_OPTS="$JAVA_OPTS -Dhttp.port=$HTTP_PORT"
    JAVA_OPTS="$JAVA_OPTS -Dajp.port=$AJP_PORT"
    JAVA_OPTS="$JAVA_OPTS -Dssl.port=$SSL_PORT"
    JAVA_OPTS="$JAVA_OPTS -Dshutdown.port=$SHUTDOWN_PORT"
    JAVA_OPTS="$JAVA_OPTS -DjvmRoute=$JVM_ROUTE"
    JAVA_OPTS="$JAVA_OPTS -Djava.library.path=${CATALINA_HOME}/lib"
    JAVA_OPTS="$JAVA_OPTS -DLOG_BASE=$LOG_BASE"

    # File encoding
    JAVA_OPTS="$JAVA_OPTS -Dfile.encoding=UTF-8 -Dfile.client.encoding=UTF-8"

#####################################
## Set Port Configuration
#####################################

    JAVA_OPTS="$JAVA_OPTS -noverify"
    JAVA_OPTS="$JAVA_OPTS -XX:+UseG1GC"
    JAVA_OPTS="$JAVA_OPTS $JVM_OPTIONS"
    JAVA_OPTS="$JAVA_OPTS -verbose:gc"
    JAVA_OPTS="$JAVA_OPTS -Xloggc:${GC_LOG_DIR}/gc.log.$DATE"
    JAVA_OPTS="$JAVA_OPTS -XX:+PrintGCDetails"
#    JAVA_OPTS="$JAVA_OPTS -XX:+PrintGCDateStamps"
#    JAVA_OPTS="$JAVA_OPTS -XX:+PrintGCTimeStamps"
#    JAVA_OPTS="$JAVA_OPTS -XX:+PrintHeapAtGC"

#    JAVA_OPTS="$JAVA_OPTS -XX:+UseGCLogFileRotation"
#    JAVA_OPTS="$JAVA_OPTS -XX:NumberOfGCLogFiles=5"
#    JAVA_OPTS="$JAVA_OPTS -XX:GCLogFileSize=2048K"

    JAVA_OPTS="$JAVA_OPTS -XX:+HeapDumpOnOutOfMemoryError"
    JAVA_OPTS="$JAVA_OPTS -XX:HeapDumpPath=${LOG_BASE}/${SERVER_NAME}.$DATE.hprof"

#    JAVA_OPTS="$JAVA_OPTS -XX:+PrintAdaptiveSizePolicy"
    JAVA_OPTS="$JAVA_OPTS -XX:+UseLargePagesInMetaspace"
#    JAVA_OPTS="$JAVA_OPTS -XX:+UseParallelGC"
    JAVA_OPTS="$JAVA_OPTS -XX:+ExplicitGCInvokesConcurrent"
    JAVA_OPTS="$JAVA_OPTS -XX:+DisableExplicitGC"

    JAVA_OPTS="$JAVA_OPTS -XX:ReservedCodeCacheSize=512m"
    JAVA_OPTS="$JAVA_OPTS -XX:-UseCodeCacheFlushing"

    JAVA_OPTS="$JAVA_OPTS -Djava.awt.headless=true"
    JAVA_OPTS="$JAVA_OPTS -Djava.net.preferIPv4Stack=true"
    JAVA_OPTS="$JAVA_OPTS -Djava.security.egd=file:/dev/urandom"

    JAVA_OPTS="$JAVA_OPTS -Dorg.apache.tomcat.websocket.DEFAULT_BUFFER_SIZE=32768"
#    JAVA_OPTS="$JAVA_OPTS -Dorg.apache.catalina.STRICT_SERVLET_COMPLIANCE=true"

    JAVA_OPTS="$JAVA_OPTS -Dsun.lang.ClassLoader.allowArraySyntax=true "
    JAVA_OPTS="$JAVA_OPTS -Dsun.rmi.dgc.client.gcInterval=3600000"
    JAVA_OPTS="$JAVA_OPTS -Dsun.rmi.dgc.server.gcInterval=3600000"

    JAVA_OPTS="$JAVA_OPTS -Dcom.sun.management.jmxremote"
    JAVA_OPTS="$JAVA_OPTS -Dcom.sun.management.jmxremote.port=$RMI_PORT"
    JAVA_OPTS="$JAVA_OPTS -Dcom.sun.management.jmxremote.local.only=false"
    JAVA_OPTS="$JAVA_OPTS -Dcom.sun.management.jmxremote.authenticate=false"
    JAVA_OPTS="$JAVA_OPTS -Dcom.sun.management.jmxremote.ssl=false"

#    JAVA_OPTS="$JAVA_OPTS -Dbind.addr=$BIND_ADDR"
#    JAVA_OPTS="$JAVA_OPTS -Dmulticast.addr=$MULTICAST_ADDR"
#    JAVA_OPTS="$JAVA_OPTS -Dcluster.recv.port=$CLUSTER_PORT"
fi

#####################################
## Athena Dolly Clustering
#####################################
export JAVA_OPTS="$JAVA_OPTS -Ddolly.properties=$CONF_DIR/dolly.properties"
#export JAVA_OPTS="$JAVA_OPTS -javaagent:$CATALINA_HOME/dolly/core-1.0.0-SNAPSHOT.jar"

#####################################
## Set Scouter Tomcat Agent
#####################################
#export JAVA_OPTS="$JAVA_OPTS -javaagent:${CATALINA_HOME}/scouter/scouter.agent.jar"
#export JAVA_OPTS="$JAVA_OPTS -Dscouter.config=${CATALINA_BASE}/scouter/conf/scouter.conf"

export JAVA_OPTS

#echo "================================================"
#echo "JAVA_HOME      =  $JAVA_HOME"
#echo "JAVA_OPTS      =  $JAVA_OPTS"
#echo "CATALINA_HOME  =  $CATALINA_HOME"
#echo "SERVER_HOME    =  $CATALINA_BASE"
#echo "HTTP_PORT      =  $HTTP_PORT"
#echo "SSL_PORT       =  $SSL_PORT"
#echo "AJP_PORT       =  $AJP_PORT"
#echo "SHUTDOWN_PORT  =  $SHUTDOWN_PORT"
#echo "================================================"

==> wasup-svr-8.5.tar.gz: wasup-svr-8.5/bin/env.sh <==
#!/bin/bash

#************************ Warning **********************************
#*                                                                 *
#* This configuration is property of OPEN SOURCE CONSULTING, INC.  *
#* Don't distribute this to other project.                         *
#*                                                                 *
#* Contact jchoi@osci.kr(http://www.osci.kr)                       *
#*******************************************************************

#####################################
# This is tomcat env.sh for iosp by Open Source Consulting, Inc
#####################################
export DATE=`date +%Y%m%d_%H%M%S`

#####################################
## Set Tomcat base env
#####################################
export JAVA_HOME=/opt/WASup/jdk/zulu8.33.0.1-jdk8.0.192-linux_x64
export SERVER_NAME=wasup-svr
export SERVER=wasup-svr
export CATALINA_HOME=/opt/WASup/engines/wasup-8.5
export CATALINA_BASE=/opt/WASup/servers/$SERVER_NAME
export CONF_DIR=${CATALINA_BASE}/conf
export LOG_BASE=${CATALINA_BASE}/logs
export GC_LOG_BASE=${LOG_BASE}/tmp

export PORT_OFFSET=0
export COMP_USER=osc

export JVM_ROUTE=$SERVER_NAME

#####################################
## Set Port Configuration
#####################################
#  Default Ports are as below       
#  HTTP_PORT	    : 8080	    
#  SSL_PORT 	    : 8443	    
#  SHUTDOWN_PORT    : 8005	    
#  RMI_PORT         : 9999	    
#####################################

CUSTOM_HTTP_PORT=
CUSTOM_AJP_PORT=
CUSTOM_SSL_PORT=
CUSTOM_SHUTDOWN_PORT=
CUSTOM_RMI_PORT=
CUSTOM_JVM_OPTIONS=

if [ "x$CUSTOM_HTTP_PORT" = "x" ]; then
    export HTTP_PORT=$(expr 8080 + $PORT_OFFSET)
else
    export HTTP_PORT=$CUSTOM_HTTP_PORT
fi

if [ "x$CUSTOM_AJP_PORT" = "x" ]; then
    export AJP_PORT=$(expr 8009 + $PORT_OFFSET)
else
    export AJP_PORT=$CUSTOM_AJP_PORT
fi

if [ "x$CUSTOM_SSL_PORT" = "x" ]; then
    export SSL_PORT=$(expr 8443 + $PORT_OFFSET)
else
    export SSL_PORT=$CUSTOM_SSL_PORT
fi

if [ "x$CUSTOM_SHUTDOWN_PORT" = "x" ]; then
    export SHUTDOWN_PORT=$(expr 8005 + $PORT_OFFSET)
else
    export SHUTDOWN_PORT=$CUSTOM_SHUTDOWN_PORT
fi

if [ "x$CUSTOM_RMI_PORT" = "x" ]; then
    export RMI_PORT=$(expr 9999 + $PORT_OFFSET)
else
    export RMI_PORT=$CUSTOM_RMI_PORT
fi

if [ "x$CUSTOM_JVM_OPTIONS" = "x" ]; then
    export JVM_OPTIONS="-Xms1024m -Xmx1024m -XX:MetaspaceSize=256m -XX:MaxMetaspaceSize=256m"
else
    export JVM_OPTIONS=$CUSTOM_JVM_OPTIONS
fi

#####################################
## JVM Parameter Configuration
#####################################

# Remove the JAVA_OPTS environment variable.
# Initialize required in case of start by WASup agent process.
unset JAVA_OPTS

if [ "x$JAVA_OPTS" = "x" ]; then
    JAVA_OPTS="-server"
    JAVA_OPTS="$JAVA_OPTS -Dserver=$SERVER"
    JAVA_OPTS="$JAVA_OPTS -Djvmid=$SERVER"
    JAVA_OPTS="$JAVA_OPTS -Dhttp.port=$HTTP_PORT"
    JAVA_OPTS="$JAVA_OPTS -Dajp.port=$AJP_PORT"
    JAVA_OPTS="$JAVA_OPTS -Dssl.port=$SSL_PORT"
    JAVA_OPTS="$JAVA_OPTS -Dshutdown.port=$SHUTDOWN_PORT"
    JAVA_OPTS="$JAVA_OPTS -DjvmRoute=$JVM_ROUTE"
    JAVA_OPTS="$JAVA_OPTS -Djava.library.path=${CATALINA_HOME}/lib"
    JAVA_OPTS="$JAVA_OPTS -DLOG_BASE=${LOG_BASE}"

    # File encoding
    JAVA_OPTS="$JAVA_OPTS -Dfile.encoding=UTF-8 -Dfile.client.encoding=UTF-8"

#####################################
## Set Port Configuration
#####################################

    JAVA_OPTS="$JAVA_OPTS -noverify"
    JAVA_OPTS="$JAVA_OPTS -XX:+UseG1GC"
    JAVA_OPTS="$JAVA_OPTS $JVM_OPTIONS"

    JAVA_OPTS="$JAVA_OPTS -XX:+UseG1GC -XX:G1ReservePercent=20 -XX:InitiatingHeapOccupancyPercent=35"
    JAVA_OPTS="$JAVA_OPTS -XX:-UseCodeCacheFlushing"
    JAVA_OPTS="$JAVA_OPTS -XX:ReservedCodeCacheSize=512m"

    JAVA_OPTS="$JAVA_OPTS -XX:+DisableExplicitGC"
    JAVA_OPTS="$JAVA_OPTS -XX:+PrintAdaptiveSizePolicy"
    JAVA_OPTS="$JAVA_OPTS -XX:+UseLargePagesInMetaspace"

    JAVA_OPTS="$JAVA_OPTS -Dorg.apache.tomcat.websocket.DEFAULT_BUFFER_SIZE=32768"

#   JAVA_OPTS="$JAVA_OPTS -verbose:gc"
    JAVA_OPTS="$JAVA_OPTS -Xloggc:$LOG_BASE/gc.log"
    JAVA_OPTS="$JAVA_OPTS -XX:+UseGCLogFileRotation -XX:NumberOfGCLogFiles=10 -XX:GCLogFileSize=5M"
    JAVA_OPTS="$JAVA_OPTS -XX:+PrintGCDetails"
    JAVA_OPTS="$JAVA_OPTS -XX:+PrintGCTimeStamps"
    JAVA_OPTS="$JAVA_OPTS -XX:-PrintTenuringDistribution"
    JAVA_OPTS="$JAVA_OPTS -XX:+HeapDumpOnOutOfMemoryError"
    JAVA_OPTS="$JAVA_OPTS -XX:HeapDumpPath=$LOG_BASE/java_${SERVER_NAME}_pid_${DATE}.hprof"

    JAVA_OPTS="$JAVA_OPTS -Djava.awt.headless=true"
    JAVA_OPTS="$JAVA_OPTS -Djava.net.preferIPv4Stack=true"
    JAVA_OPTS="$JAVA_OPTS -Djava.security.egd=file:/dev/urandom"

    JAVA_OPTS="$JAVA_OPTS -Dorg.apache.tomcat.websocket.DEFAULT_BUFFER_SIZE=32768"
#    JAVA_OPTS="$JAVA_OPTS -Dorg.apache.catalina.STRICT_SERVLET_COMPLIANCE=true"

    JAVA_OPTS="$JAVA_OPTS -Dsun.lang.ClassLoader.allowArraySyntax=true "
    JAVA_OPTS="$JAVA_OPTS -Dsun.rmi.dgc.client.gcInterval=3600000"
    JAVA_OPTS="$JAVA_OPTS -Dsun.rmi.dgc.server.gcInterval=3600000"

    JAVA_OPTS="$JAVA_OPTS -Dcom.sun.management.jmxremote"
    JAVA_OPTS="$JAVA_OPTS -Dcom.sun.management.jmxremote.port=$RMI_PORT"
    JAVA_OPTS="$JAVA_OPTS -Dcom.sun.management.jmxremote.local.only=false"
    JAVA_OPTS="$JAVA_OPTS -Dcom.sun.management.jmxremote.authenticate=false"
    JAVA_OPTS="$JAVA_OPTS -Dcom.sun.management.jmxremote.ssl=false"

fi

#####################################
## Athena Dolly Clustering
#####################################
export JAVA_OPTS="$JAVA_OPTS -Ddolly.properties=$CONF_DIR/dolly.properties"
#export JAVA_OPTS="$JAVA_OPTS -javaagent:$CATALINA_HOME/dolly/core-1.0.0-SNAPSHOT.jar"

#####################################
## Set Scouter Tomcat Agent
#####################################
#export JAVA_OPTS="$JAVA_OPTS -javaagent:${CATALINA_HOME}/scouter/scouter.agent.jar"
#export JAVA_OPTS="$JAVA_OPTS -Dscouter.config=${CATALINA_BASE}/scouter/conf/scouter.conf"

export JAVA_OPTS

#echo "================================================"
#echo "JAVA_HOME      =  $JAVA_HOME"
#echo "JAVA_OPTS      =  $JAVA_OPTS"
#echo "CATALINA_HOME  =  $CATALINA_HOME"
#echo "SERVER_HOME    =  $CATALINA_BASE"
#echo "HTTP_PORT      =  $HTTP_PORT"
#echo "SSL_PORT       =  $SSL_PORT"
#echo "AJP_PORT       =  $AJP_PORT"
#echo "SHUTDOWN_PORT  =  $SHUTDOWN_PORT"
#echo "================================================"
